#ifndef	_PKTINFO_H
#define	_PKTINFO_H

#include	<sys/time.h>
#include	<unistd.h>

typedef	struct	ether_header	ETH_HDR	;
typedef	struct	ether_arp	ETH_ARP	;
typedef	struct	ip		IP	;
typedef	struct	tcphdr		TCP_HDR	;
typedef	struct	udphdr		UDP_HDR	;
typedef	struct	icmphdr		ICMP	;
typedef	struct	timeval		TVAL	;

struct	TCPHASH	;

/*  PktInfo								*/
/*  This class is used to record decoded packet information for use	*/
/*  by the graphic and packet display objects. The EPoint structure is	*/
/*  used for IP endpoints (source and destination), and _PIHdr for the	*/
/*  libpcap-level capture information.					*/

struct	EPoint
{	char	*a		;	/* Address			*/
	char	*n		;	/* Host name			*/
	char	*p		;	/* Port				*/
	char	*s		;	/* Service			*/
}	;

enum	Direction
{	Incoming	= 0,		/* Packet is incoming		*/
	Outgoing	= 1,		/* Packet is outgoing		*/
	Passing		= 2,		/* Strangers on a train		*/
	Local		= 3,		/* Looping back			*/
	Unknown		= 4		/* We can work it out (not)	*/
}	;

struct	_PIHdr
{
	int	caplen		;	/* Captured data length		*/
	int	pktlen		;	/* Actual packet length		*/
	TVAL	tval		;	/* Packet time			*/
	int	accept		;	/* Accepted packet count	*/
	int	dropped		;	/* Dropped  packet count	*/
	int	missed		;	/* Missed packet count		*/
}	;


struct	PktInfo
{
	PktInfo	  *next		;	/* Next on free queue		*/
	int	  tag		;	/* Block contents tag		*/

	_PIHdr	  piHdr		;	/* Raw header information	*/
	char	  data[1518]	;	/* Raw data buffer		*/

	bool	  decoded	;	/* Packet decoded flag		*/
	int	  datlen	;	/* Data length in packet	*/
	int	  ago		;	/* Age relative to current time	*/
	int	  usecnt	;	/* Structure use count		*/

	/* The next set of fields are set by the packet decode routines	*/
	/* and are displayed by the Packets module.			*/
	char	  time	[20]	;	/* Packet time stamp		*/
	char	  proto	[20]	;	/* Protocol			*/
	EPoint	  srce		;	/* Source			*/
	EPoint	  dest		;	/* Destination			*/
	char	  info	[96]	;	/* Miscellaneous information	*/
	char	  size	[24]	;	/* Sizes as a string		*/

	/* Next follow other fields set by the packet decode routines,	*/
	/* which are used by the packet details and TCP/IP data display	*/
	/* functions.							*/
	ETH_ARP	  *arp		;	/* ARP packet pointer		*/
	IP	  *ip		;	/* IP packet pointer		*/
	char	  *ipdata	;	/* IP data pointer		*/
	TCPHASH	  *tcphash	;	/* TCP conversation		*/
	bool	  rev		;	/* Conversation reversed flag	*/
}	;

#define	PKDATSZ	(sizeof(_PIHdr) + 1518)


#endif	/* _PKTINFO_H */
